@@ -8,6 +8,7 @@ import subprocess
 
 import click
 from click import echo
+from emoji import emojize
 
 
 @click.group()
@@ -101,9 +102,16 @@ def deploy(t: str) -> None:
 
 def say_message() -> None:
 
+    anatomical_heart = emojize(":anatomical heart:")
+    mechanical_arm = emojize(":mechanical_arm:")
+    call_me_hand = emojize(":call_me_hand:")
+    sailing_ship = emojize(":sailboat:")
+
     message = (
-        "U+1FAC Lia is an open-source CI/CD tool that eliminates the Fel U+1F9BE"
-        " Copyright © 2023 Soul Twin Records U+1F919, a subsidiary of SailBlack Inc."
+        f"{anatomical_heart} Lia is an open-source CI/CD tool "
+        f"that eliminates the Fel {mechanical_arm}"
+        f" Copyright © 2023 Soul Twin Records {call_me_hand}, "
+        f"a subsidiary of SailBlack Inc. {sailing_ship}"
     )
     echo(message=message)
 
